summaryrefslogtreecommitdiff
path: root/lib/sqlalchemy/dialects/postgresql/ext.py
diff options
context:
space:
mode:
authorMike Bayer <mike_mp@zzzcomputing.com>2020-04-14 13:15:21 -0400
committerMike Bayer <mike_mp@zzzcomputing.com>2020-04-14 13:15:21 -0400
commitcea03be855514d592b6671fa6dbc074a19a795fb (patch)
treef127540bda77a4ea5d9935cffedf04d8b01776a9 /lib/sqlalchemy/dialects/postgresql/ext.py
parenta898ade3bc36ca27cf9475d1348249646eb40e95 (diff)
downloadsqlalchemy-cea03be855514d592b6671fa6dbc074a19a795fb.tar.gz
Run search and replace of symbolic module names
Replaces a wide array of Sphinx-relative doc references with an abbreviated absolute form now supported by zzzeeksphinx. Change-Id: I94bffcc3f37885ffdde6238767224296339698a2
Diffstat (limited to 'lib/sqlalchemy/dialects/postgresql/ext.py')
-rw-r--r--lib/sqlalchemy/dialects/postgresql/ext.py20
1 files changed, 12 insertions, 8 deletions
diff --git a/lib/sqlalchemy/dialects/postgresql/ext.py b/lib/sqlalchemy/dialects/postgresql/ext.py
index f11919b4b..e64920719 100644
--- a/lib/sqlalchemy/dialects/postgresql/ext.py
+++ b/lib/sqlalchemy/dialects/postgresql/ext.py
@@ -46,7 +46,7 @@ class aggregate_order_by(expression.ColumnElement):
.. seealso::
- :class:`.array_agg`
+ :class:`_functions.array_agg`
"""
@@ -113,7 +113,8 @@ class ExcludeConstraint(ColumnCollectionConstraint):
where=(Column('group') != 'some group')
)
- The constraint is normally embedded into the :class:`.Table` construct
+ The constraint is normally embedded into the :class:`_schema.Table`
+ construct
directly, or added later using :meth:`.append_constraint`::
some_table = Table(
@@ -136,11 +137,14 @@ class ExcludeConstraint(ColumnCollectionConstraint):
A sequence of two tuples of the form ``(column, operator)`` where
"column" is a SQL expression element or a raw SQL string, most
- typically a :class:`.Column` object, and "operator" is a string
+ typically a :class:`_schema.Column` object,
+ and "operator" is a string
containing the operator to use. In order to specify a column name
- when a :class:`.Column` object is not available, while ensuring
+ when a :class:`_schema.Column` object is not available,
+ while ensuring
that any necessary quoting rules take effect, an ad-hoc
- :class:`.Column` or :func:`.sql.expression.column` object should be
+ :class:`_schema.Column` or :func:`_expression.column`
+ object should be
used.
:param name:
@@ -230,9 +234,9 @@ class ExcludeConstraint(ColumnCollectionConstraint):
def array_agg(*arg, **kw):
- """PostgreSQL-specific form of :class:`.array_agg`, ensures
- return type is :class:`.postgresql.ARRAY` and not
- the plain :class:`.types.ARRAY`, unless an explicit ``type_``
+ """PostgreSQL-specific form of :class:`_functions.array_agg`, ensures
+ return type is :class:`_postgresql.ARRAY` and not
+ the plain :class:`_types.ARRAY`, unless an explicit ``type_``
is passed.
.. versionadded:: 1.1